==> sawmill6.4b3_crypt_src.tar.gz: sawmill-6.4b3/S21d6f40cfb511982e4424e0e250a9557.cpp <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// then compilation!



















































 
#include "sconfig.h"

#include "Sbfc9cb0c7c2fe6f4e17de2219c571a09.h"

#if HAVE_STDLIB_H
 
#include <stdlib.h>

#endif
 
#include "S21d6f40cfb511982e4424e0e250a9557.h"

#include "Sb55824cd22e362581a8a09954133e17b.h"

#include "S88207d8b9471e1c243fee0e2242bb81b.h"

#include "S033c90fd2ff4888be82b5e1092fc89eb.h"

#include "S02018c21aae4cfd793a8f80f191dec71.h"

#include "S502c2d5425ba2c329e58f02e0bf84d5e.h"
  S71c7ae294b7abd866b3fb295b3b9e4a4::S71c7ae294b7abd866b3fb295b3b9e4a4(Se812b5a98988bad1d5b8df118cb6cc7f 
&S8c9a70dc1e604715e475d87430ba602d, unsigned long S95d1bf88a559deafe375887f06397ad6) : S4d682ec4eed27c53849758bc13b6e179(S8c9a70dc1e604715e475d87430ba602d) 
{ S6953e4854c62b9a1b6ab847420bc2657 = 10; Saf6c0c3c714d1f5ab0d299b2cbf50060(S46ab2997ca006d78b35db8f6f9de7662 
= (S801787aae743c33ff4c8bb4573d6e834 *) S69d014b769e6f390ab59e42ff5dc9571(S6953e4854c62b9a1b6ab847420bc2657 
* sizeof(S801787aae743c33ff4c8bb4573d6e834), "allocating session hits buffer")); S4d682ec4eed27c53849758bc13b6e179.S1d8d5e912302108b5e88c3e77fcad378.Se1493a172a6c69298725b98e4efad119->S1ab244d34d25603f7a6a42af69ed2a62 
+= S6953e4854c62b9a1b6ab847420bc2657 * sizeof(S801787aae743c33ff4c8bb4573d6e834); Sdbafe8ea0e760f218e0d143d749f38c0 
= 0; Sbfc2f1258f0cd825b9033f17aa88332f = S95d1bf88a559deafe375887f06397ad6; }  S71c7ae294b7abd866b3fb295b3b9e4a4::~S71c7ae294b7abd866b3fb295b3b9e4a4() 
{ S4d682ec4eed27c53849758bc13b6e179.S1d8d5e912302108b5e88c3e77fcad378.Se1493a172a6c69298725b98e4efad119->S1ab244d34d25603f7a6a42af69ed2a62 
-= S6953e4854c62b9a1b6ab847420bc2657 * sizeof(S801787aae743c33ff4c8bb4573d6e834); S8542634d1f0eb6829badb2e1f5d42138(S46ab2997ca006d78b35db8f6f9de7662); 
}   void S71c7ae294b7abd866b3fb295b3b9e4a4::S54f5228c896f1184d33d165903cfe009(time_t Sdfeaaeb4316477bd556ea5e8c3295887, 
unsigned long Saa57674281c2b86e21fa6f0dc727d8f4) {  if (Sdbafe8ea0e760f218e0d143d749f38c0 == S6953e4854c62b9a1b6ab847420bc2657) 
{   S4d682ec4eed27c53849758bc13b6e179.S1d8d5e912302108b5e88c3e77fcad378.Se1493a172a6c69298725b98e4efad119->S1ab244d34d25603f7a6a42af69ed2a62 
-= S6953e4854c62b9a1b6ab847420bc2657 * sizeof(S801787aae743c33ff4c8bb4573d6e834); S6953e4854c62b9a1b6ab847420bc2657 
*= 2; Saf6c0c3c714d1f5ab0d299b2cbf50060(S46ab2997ca006d78b35db8f6f9de7662 = (S801787aae743c33ff4c8bb4573d6e834 
*) Sbd9ba3c24e0f838ee3928e31db9440fd(S46ab2997ca006d78b35db8f6f9de7662, S6953e4854c62b9a1b6ab847420bc2657 
* sizeof(S801787aae743c33ff4c8bb4573d6e834), "reallocating session hits buffer")); S4d682ec4eed27c53849758bc13b6e179.S1d8d5e912302108b5e88c3e77fcad378.Se1493a172a6c69298725b98e4efad119->S1ab244d34d25603f7a6a42af69ed2a62 
+= S6953e4854c62b9a1b6ab847420bc2657 * sizeof(S801787aae743c33ff4c8bb4573d6e834); }   S46ab2997ca006d78b35db8f6f9de7662[Sdbafe8ea0e760f218e0d143d749f38c0].Saa57674281c2b86e21fa6f0dc727d8f4 
= Saa57674281c2b86e21fa6f0dc727d8f4; S46ab2997ca006d78b35db8f6f9de7662[Sdbafe8ea0e760f218e0d143d749f38c0].Sdfeaaeb4316477bd556ea5e8c3295887 
= Sdfeaaeb4316477bd556ea5e8c3295887;  Sdbafe8ea0e760f218e0d143d749f38c0++; }   bool S71c7ae294b7abd866b3fb295b3b9e4a4::Sb712c64dfcf9850c72f2466d63777e00(unsigned 
long Saa57674281c2b86e21fa6f0dc727d8f4) {  for (unsigned long S865c0c0b4ab0e063e5caa3387c1a8741 = 0; 
S865c0c0b4ab0e063e5caa3387c1a8741 < Sdbafe8ea0e760f218e0d143d749f38c0; S865c0c0b4ab0e063e5caa3387c1a8741++) 
if (S46ab2997ca006d78b35db8f6f9de7662[S865c0c0b4ab0e063e5caa3387c1a8741].Saa57674281c2b86e21fa6f0dc727d8f4 
== Saa57674281c2b86e21fa6f0dc727d8f4) return true;  return false; }   extern "C" int Sbab56a85bc1f28e561ae2e8648ed04c8(const 
void *Sec6ef230f1828039ee794566b9c58adc, const void *S1d665b9b1467944c128a5575119d1cfd) { S801787aae743c33ff4c8bb4573d6e834 
*S115032b14c56fb00e657abeb69c1b726 = (S801787aae743c33ff4c8bb4573d6e834 *) Sec6ef230f1828039ee794566b9c58adc; 
S801787aae743c33ff4c8bb4573d6e834 *S9009ec734775d6bf6f996f11fd866382 = (S801787aae743c33ff4c8bb4573d6e834 
*) S1d665b9b1467944c128a5575119d1cfd; return (S115032b14c56fb00e657abeb69c1b726->Sdfeaaeb4316477bd556ea5e8c3295887 
- S9009ec734775d6bf6f996f11fd866382->Sdfeaaeb4316477bd556ea5e8c3295887); } void S71c7ae294b7abd866b3fb295b3b9e4a4::S6b46ae48421828d9973deec5fa9aa0c3(void) 
{ qsort(S46ab2997ca006d78b35db8f6f9de7662, Sdbafe8ea0e760f218e0d143d749f38c0, sizeof(S801787aae743c33ff4c8bb4573d6e834), 
Sbab56a85bc1f28e561ae2e8648ed04c8); }  S1356d0666866080ee569a8007f7465e0 &operator << (S1356d0666866080ee569a8007f7465e0 
&Sd95679752134a2d9eb61dbd7b91c4bcc, const S71c7ae294b7abd866b3fb295b3b9e4a4 &S21d6f40cfb511982e4424e0e250a9557) 
{ Sd95679752134a2d9eb61dbd7b91c4bcc << "(" << S21d6f40cfb511982e4424e0e250a9557.Sdbafe8ea0e760f218e0d143d749f38c0 
<< " hits): "; for (unsigned long S865c0c0b4ab0e063e5caa3387c1a8741 = 0; S865c0c0b4ab0e063e5caa3387c1a8741 
< S21d6f40cfb511982e4424e0e250a9557.Sdbafe8ea0e760f218e0d143d749f38c0; S865c0c0b4ab0e063e5caa3387c1a8741++) 
Sd95679752134a2d9eb61dbd7b91c4bcc << "[" << S4de0db57e8c88052e07ab27f12e93c75(S21d6f40cfb511982e4424e0e250a9557.S4d682ec4eed27c53849758bc13b6e179, 
S21d6f40cfb511982e4424e0e250a9557.S4d682ec4eed27c53849758bc13b6e179.S1d8d5e912302108b5e88c3e77fcad378.Secec0d258f80607d3360331f00e86cd9, 
S21d6f40cfb511982e4424e0e250a9557.S46ab2997ca006d78b35db8f6f9de7662[S865c0c0b4ab0e063e5caa3387c1a8741].Saa57674281c2b86e21fa6f0dc727d8f4) 
<< " at " << S21d6f40cfb511982e4424e0e250a9557.S46ab2997ca006d78b35db8f6f9de7662[S865c0c0b4ab0e063e5caa3387c1a8741].Sdfeaaeb4316477bd556ea5e8c3295887 
<< "] "; return Sd95679752134a2d9eb61dbd7b91c4bcc; }

==> sawmill6.4.5_crypt_src.tar.gz: sawmill-6.4.5/S21d6f40cfb511982e4424e0e250a9557.cpp <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// than compilation!



















































 
#include "sconfig.h"

#include "Sbfc9cb0c7c2fe6f4e17de2219c571a09.h"

#if HAVE_STDLIB_H
 
#include <stdlib.h>

#endif
 
#include "S21d6f40cfb511982e4424e0e250a9557.h"

#include "Sb55824cd22e362581a8a09954133e17b.h"

#include "S88207d8b9471e1c243fee0e2242bb81b.h"

#include "S033c90fd2ff4888be82b5e1092fc89eb.h"

#include "S02018c21aae4cfd793a8f80f191dec71.h"

#include "S502c2d5425ba2c329e58f02e0bf84d5e.h"
  S71c7ae294b7abd866b3fb295b3b9e4a4::S71c7ae294b7abd866b3fb295b3b9e4a4(Se812b5a98988bad1d5b8df118cb6cc7f 
&S8c9a70dc1e604715e475d87430ba602d, unsigned long S95d1bf88a559deafe375887f06397ad6) : S4d682ec4eed27c53849758bc13b6e179(S8c9a70dc1e604715e475d87430ba602d) 
{ S6953e4854c62b9a1b6ab847420bc2657 = 10; Saf6c0c3c714d1f5ab0d299b2cbf50060(S46ab2997ca006d78b35db8f6f9de7662 
= (S801787aae743c33ff4c8bb4573d6e834 *) S69d014b769e6f390ab59e42ff5dc9571((S6953e4854c62b9a1b6ab847420bc2657 
+ 1) * sizeof(S801787aae743c33ff4c8bb4573d6e834), "allocating session hits buffer")); S4d682ec4eed27c53849758bc13b6e179.S1d8d5e912302108b5e88c3e77fcad378.Se1493a172a6c69298725b98e4efad119->S1ab244d34d25603f7a6a42af69ed2a62 
+= S6953e4854c62b9a1b6ab847420bc2657 * sizeof(S801787aae743c33ff4c8bb4573d6e834); Sdbafe8ea0e760f218e0d143d749f38c0 
= 0; Sbfc2f1258f0cd825b9033f17aa88332f = S95d1bf88a559deafe375887f06397ad6; }  S71c7ae294b7abd866b3fb295b3b9e4a4::~S71c7ae294b7abd866b3fb295b3b9e4a4() 
{ S4d682ec4eed27c53849758bc13b6e179.S1d8d5e912302108b5e88c3e77fcad378.Se1493a172a6c69298725b98e4efad119->S1ab244d34d25603f7a6a42af69ed2a62 
-= S6953e4854c62b9a1b6ab847420bc2657 * sizeof(S801787aae743c33ff4c8bb4573d6e834); S8542634d1f0eb6829badb2e1f5d42138(S46ab2997ca006d78b35db8f6f9de7662); 
}   void S71c7ae294b7abd866b3fb295b3b9e4a4::S54f5228c896f1184d33d165903cfe009(time_t Sdfeaaeb4316477bd556ea5e8c3295887, 
unsigned long Saa57674281c2b86e21fa6f0dc727d8f4) {  if (Sdbafe8ea0e760f218e0d143d749f38c0 == S6953e4854c62b9a1b6ab847420bc2657) 
{   S4d682ec4eed27c53849758bc13b6e179.S1d8d5e912302108b5e88c3e77fcad378.Se1493a172a6c69298725b98e4efad119->S1ab244d34d25603f7a6a42af69ed2a62 
-= S6953e4854c62b9a1b6ab847420bc2657 * sizeof(S801787aae743c33ff4c8bb4573d6e834); S6953e4854c62b9a1b6ab847420bc2657 
*= 2; Saf6c0c3c714d1f5ab0d299b2cbf50060(S46ab2997ca006d78b35db8f6f9de7662 = (S801787aae743c33ff4c8bb4573d6e834 
*) Sbd9ba3c24e0f838ee3928e31db9440fd(S46ab2997ca006d78b35db8f6f9de7662, S6953e4854c62b9a1b6ab847420bc2657 
* sizeof(S801787aae743c33ff4c8bb4573d6e834), "reallocating session hits buffer")); S4d682ec4eed27c53849758bc13b6e179.S1d8d5e912302108b5e88c3e77fcad378.Se1493a172a6c69298725b98e4efad119->S1ab244d34d25603f7a6a42af69ed2a62 
+= S6953e4854c62b9a1b6ab847420bc2657 * sizeof(S801787aae743c33ff4c8bb4573d6e834); }   S46ab2997ca006d78b35db8f6f9de7662[Sdbafe8ea0e760f218e0d143d749f38c0].Saa57674281c2b86e21fa6f0dc727d8f4 
= Saa57674281c2b86e21fa6f0dc727d8f4; S46ab2997ca006d78b35db8f6f9de7662[Sdbafe8ea0e760f218e0d143d749f38c0].Sdfeaaeb4316477bd556ea5e8c3295887 
= Sdfeaaeb4316477bd556ea5e8c3295887;  Sdbafe8ea0e760f218e0d143d749f38c0++; }   bool S71c7ae294b7abd866b3fb295b3b9e4a4::Sb712c64dfcf9850c72f2466d63777e00(unsigned 
long Saa57674281c2b86e21fa6f0dc727d8f4) {  for (unsigned long S865c0c0b4ab0e063e5caa3387c1a8741 = 0; 
S865c0c0b4ab0e063e5caa3387c1a8741 < Sdbafe8ea0e760f218e0d143d749f38c0; S865c0c0b4ab0e063e5caa3387c1a8741++) 
if (S46ab2997ca006d78b35db8f6f9de7662[S865c0c0b4ab0e063e5caa3387c1a8741].Saa57674281c2b86e21fa6f0dc727d8f4 
== Saa57674281c2b86e21fa6f0dc727d8f4) return true;  return false; }   extern "C" int Sbab56a85bc1f28e561ae2e8648ed04c8(const 
void *Sec6ef230f1828039ee794566b9c58adc, const void *S1d665b9b1467944c128a5575119d1cfd) { S801787aae743c33ff4c8bb4573d6e834 
*S115032b14c56fb00e657abeb69c1b726 = (S801787aae743c33ff4c8bb4573d6e834 *) Sec6ef230f1828039ee794566b9c58adc; 
S801787aae743c33ff4c8bb4573d6e834 *S9009ec734775d6bf6f996f11fd866382 = (S801787aae743c33ff4c8bb4573d6e834 
*) S1d665b9b1467944c128a5575119d1cfd; return (S115032b14c56fb00e657abeb69c1b726->Sdfeaaeb4316477bd556ea5e8c3295887 
- S9009ec734775d6bf6f996f11fd866382->Sdfeaaeb4316477bd556ea5e8c3295887); } void S71c7ae294b7abd866b3fb295b3b9e4a4::S6b46ae48421828d9973deec5fa9aa0c3(void) 
{ qsort(S46ab2997ca006d78b35db8f6f9de7662, Sdbafe8ea0e760f218e0d143d749f38c0, sizeof(S801787aae743c33ff4c8bb4573d6e834), 
Sbab56a85bc1f28e561ae2e8648ed04c8); }  S1356d0666866080ee569a8007f7465e0 &operator << (S1356d0666866080ee569a8007f7465e0 
&Sd95679752134a2d9eb61dbd7b91c4bcc, const S71c7ae294b7abd866b3fb295b3b9e4a4 &S21d6f40cfb511982e4424e0e250a9557) 
{ Sd95679752134a2d9eb61dbd7b91c4bcc << "(" << S21d6f40cfb511982e4424e0e250a9557.Sdbafe8ea0e760f218e0d143d749f38c0 
<< " hits): "; for (unsigned long S865c0c0b4ab0e063e5caa3387c1a8741 = 0; S865c0c0b4ab0e063e5caa3387c1a8741 
< S21d6f40cfb511982e4424e0e250a9557.Sdbafe8ea0e760f218e0d143d749f38c0; S865c0c0b4ab0e063e5caa3387c1a8741++) 
Sd95679752134a2d9eb61dbd7b91c4bcc << "[" << S4de0db57e8c88052e07ab27f12e93c75(S21d6f40cfb511982e4424e0e250a9557.S4d682ec4eed27c53849758bc13b6e179, 
S21d6f40cfb511982e4424e0e250a9557.S4d682ec4eed27c53849758bc13b6e179.S1d8d5e912302108b5e88c3e77fcad378.Secec0d258f80607d3360331f00e86cd9, 
S21d6f40cfb511982e4424e0e250a9557.S46ab2997ca006d78b35db8f6f9de7662[S865c0c0b4ab0e063e5caa3387c1a8741].Saa57674281c2b86e21fa6f0dc727d8f4) 
<< " at " << S21d6f40cfb511982e4424e0e250a9557.S46ab2997ca006d78b35db8f6f9de7662[S865c0c0b4ab0e063e5caa3387c1a8741].Sdfeaaeb4316477bd556ea5e8c3295887 
<< "] "; return Sd95679752134a2d9eb61dbd7b91c4bcc; }
